"use client";

import { ChakraProvider, ThemeConfig } from "@chakra-ui/react";
import { CacheProvider } from "@chakra-ui/next-js";
import theme from "@/theme/theme";
import { GeneralProvider } from "@/contexts/GeneralContext";
import "@/styles/App.css";
import "@/styles/Contact.css";
import "@/styles/MiniCalendar.css";
import { SessionProvider } from "next-auth/react";
import { User, AssignmentStatus } from "next-auth";

export default function Providers({
  currentUser,
  batchStatus,
  currentProjectId,
  locationStatus,
  assignmentStatus,
  projects,
  children
}: {
  currentUser: User;
  batchStatus: string[];
  locationStatus: string[];
  assignmentStatus: AssignmentStatus[];
  projects: string[];
  children: React.ReactNode;
  currentProjectId: string;
}) {
  return (
    <CacheProvider>
      <ChakraProvider theme={theme}>
        <SessionProvider>
          <GeneralProvider
            user={currentUser}
            batchStatus={batchStatus}
            locationStatus={locationStatus}
            assignmentStatus={assignmentStatus}
            projects={projects}
            currentProjectId={currentProjectId}
          >
            {children}
          </GeneralProvider>
        </SessionProvider>
      </ChakraProvider>
    </CacheProvider>
  );
}
